@@ -35,47 +35,43 @@
 #include "testing/base/public/gunit_prod.h"
 
 namespace mozc {
+class ConversionRequest;
+class ImmutableConverterInterface;
 class Segments;
 class UserDatamanagerInterface;
-class ImmutableConverterInterface;
 
 class ConverterImpl : public ConverterInterface {
  public:
   ConverterImpl();
   virtual ~ConverterImpl();
 
-  bool Predict(Segments *segments,
+  bool Predict(const ConversionRequest &request,
                const string &key,
-               const Segments::RequestType request_type) const;
+               const Segments::RequestType request_type,
+               Segments *segments) const;
 
   bool StartConversionForRequest(const ConversionRequest &request,
                                  Segments *segments) const;
   bool StartConversion(Segments *segments,
                        const string &key) const;
-  bool StartConversionWithComposer(Segments *segments,
-                                   const composer::Composer *composer) const;
   bool StartReverseConversion(Segments *segments,
                               const string &key) const;
   bool StartPredictionForRequest(const ConversionRequest &request,
                                  Segments *segments) const;
   bool StartPrediction(Segments *segments,
                        const string &key) const;
-  bool StartPredictionWithComposer(Segments *segments,
-                                   const composer::Composer *composer) const;
+  bool StartSuggestionForRequest(const ConversionRequest &request,
+                                 Segments *segments) const;
   bool StartSuggestion(Segments *segments,
                        const string &key) const;
-  bool StartSuggestionWithComposer(Segments *segments,
-                                   const composer::Composer *composer) const;
+  bool StartPartialPredictionForRequest(const ConversionRequest &request,
+                                        Segments *segments) const;
   bool StartPartialPrediction(Segments *segments,
                               const string &key) const;
-  bool StartPartialPredictionWithComposer(
-      Segments *segments,
-      const composer::Composer *composer) const;
+  bool StartPartialSuggestionForRequest(const ConversionRequest &request,
+                                        Segments *segments) const;
   bool StartPartialSuggestion(Segments *segments,
                               const string &key) const;
-  bool StartPartialSuggestionWithComposer(
-      Segments *segments,
-      const composer::Composer *composer) const;
 
   bool FinishConversion(Segments *segments) const;
   bool CancelConversion(Segments *segments) const;
@@ -97,9 +93,11 @@ class ConverterImpl : public ConverterInterface {
   bool SubmitFirstSegment(Segments *segments,
                           size_t candidate_index) const;
   bool ResizeSegment(Segments *segments,
+                     const ConversionRequest &requset,
                      size_t segment_index,
                      int offset_length) const;
   bool ResizeSegment(Segments *segments,
+                     const ConversionRequest &requset,
                      size_t start_segment_index,
                      size_t segments_size,
                      const uint8 *new_size_array,
