@@ -32,6 +32,7 @@
 
 #include <string>
 #include "base/base.h"
+#include "converter/conversion_request.h"
 #include "converter/segments.h"
 
 namespace mozc {
@@ -41,20 +42,6 @@ namespace composer {
   class Composer;
 }  // namespace composer
 
-// Contains utilizable information for conversion, including composition,
-// preceding text, etc.
-struct ConversionRequest {
-  explicit ConversionRequest(const composer::Composer *c) : composer(c) {}
-
-  // Required field
-  // Input composer to generate a key for conversion.
-  const composer::Composer *composer;
-
-  // Optional field
-  // If nonempty, utilizes this preceding text for conversion.
-  string preceding_text;
-};
-
 class ConverterInterface {
  public:
   // Starts conversion for given request.
@@ -66,10 +53,6 @@ class ConverterInterface {
   virtual bool StartConversion(Segments *segments,
                                const string &key) const = 0;
 
-  // Start conversion with composer.
-  virtual bool StartConversionWithComposer(
-      Segments *segments, const composer::Composer *composer) const = 0;
-
   // Start reverse conversion with key.
   virtual bool StartReverseConversion(Segments *segments,
                                       const string &key) const = 0;
@@ -82,33 +65,73 @@ class ConverterInterface {
   virtual bool StartPrediction(Segments *segments,
                                const string &key) const = 0;
 
-  // Start prediction with composer.
+  // DEPRECATED. Start prediction with composer.
+  // TODO(noriyukit): Remove this method.
   virtual bool StartPredictionWithComposer(
-      Segments *segments, const composer::Composer *composer) const = 0;
+      Segments *segments, const composer::Composer *composer) const {
+    DCHECK(composer);
+    DLOG(WARNING) << ("StartPredictionWithComposer() is deprecated. "
+                      "Use StartPredictionForRequest() instead.");
+    return StartPredictionForRequest(ConversionRequest(composer), segments);
+  }
+
+  // Starts suggestion for given request.
+  virtual bool StartSuggestionForRequest(const ConversionRequest &request,
+                                         Segments *segments) const = 0;
 
   // Start suggestion with key (request_type = SUGGESTION)
   virtual bool StartSuggestion(Segments *segments,
                                const string &key) const = 0;
 
-  // Start suggestion with composer.
+  // DEPRECATED. Start suggestion with composer.
+  // TODO(noriyukit): Remove this method.
   virtual bool StartSuggestionWithComposer(
-      Segments *segments, const composer::Composer *composer) const = 0;
+      Segments *segments, const composer::Composer *composer) const {
+    DCHECK(composer);
+    DLOG(WARNING) << ("StartSuggestionWithComposer() is deprecated. "
+                      "Use StartSuggestionForRequest() instead.");
+    return StartSuggestionForRequest(ConversionRequest(composer), segments);
+  }
+
+  // Starts partial prediction for given request.
+  virtual bool StartPartialPredictionForRequest(
+      const ConversionRequest &request, Segments *segments) const = 0;
 
   // Start prediction with key (request_type = PARTIAL_PREDICTION)
   virtual bool StartPartialPrediction(Segments *segments,
                                       const string &key) const = 0;
 
+  // DEPRECATED.
   // Start prediction with composer (request_type = PARTIAL_PREDICTION)
+  // TODO(noriyukit): Remove this method.
   virtual bool StartPartialPredictionWithComposer(
-      Segments *segments, const composer::Composer *composer) const = 0;
+      Segments *segments, const composer::Composer *composer) const {
+    DCHECK(composer);
+    DLOG(WARNING) << ("StartPartialPredictionWithComposer() is deprecated. "
+                      "Use StartPartialPredictionForRequest() instead.");
+    return StartPartialPredictionForRequest(ConversionRequest(composer),
+                                            segments);
+  }
+
+  // Starts partial suggestion for given request.
+  virtual bool StartPartialSuggestionForRequest(
+      const ConversionRequest &request, Segments *segments) const = 0;
 
   // Start suggestion with key (request_type = PARTIAL_SUGGESTION)
   virtual bool StartPartialSuggestion(Segments *segments,
                                       const string &key) const = 0;
 
+  // DEPRECATED.
   // Start suggestion with composer (request_type = PARTIAL_SUGGESTION)
+  // TODO(noriyukit): Remove this method.
   virtual bool StartPartialSuggestionWithComposer(
-      Segments *segments, const composer::Composer *composer) const = 0;
+      Segments *segments, const composer::Composer *composer) const {
+    DCHECK(composer);
+    DLOG(WARNING) << ("StartPartialSuggestionWithComposer() is deprecated. "
+                      "Use StartPartialSuggestionForRequest() instead.");
+    return StartPartialSuggestionForRequest(ConversionRequest(composer),
+                                            segments);
+  }
 
   // Finish conversion.
   // Segments are cleared. Context is not clreared
@@ -175,6 +198,7 @@ class ConverterInterface {
   // Resize segment_index-th segment by offset_length.
   // offset_lenth can be negative.
   virtual bool ResizeSegment(Segments *segments,
+                             const ConversionRequest &request,
                              size_t segment_index,
                              int offset_length) const = 0;
 
@@ -182,6 +206,7 @@ class ConverterInterface {
   // segments with the new size in new_size_array.
   // size of new_size_array is specified in 'array_size'
   virtual bool ResizeSegment(Segments *segments,
+                             const ConversionRequest &request,
                              size_t start_segment_index,
                              size_t segments_size,
                              const uint8 *new_size_array,
