@@ -43,7 +43,10 @@
 #include "composer/composer.h"
 #include "config/config.pb.h"
 #include "config/config_handler.h"
+#include "converter/conversion_request.h"
+#include "converter/node_allocator.h"
 #include "converter/segments.h"
+#include "dictionary/dictionary_interface.h"
 #include "dictionary/suppression_dictionary.h"
 #include "prediction/predictor_interface.h"
 #include "prediction/user_history_predictor.pb.h"
@@ -131,9 +134,11 @@ string GetDescription(const Segment::Candidate &candidate) {
   return candidate.description;
 }
 
+}  // namespace
+
 // Returns true if the input first candidate seems to be a privacy sensitive
 // such like password.
-bool IsPrivacySensitive(const Segments *segments) {
+bool UserHistoryPredictor::IsPrivacySensitive(const Segments *segments) const {
   const bool kNonSensitive = false;
   const bool kSensitive = true;
 
@@ -176,12 +181,29 @@ bool IsPrivacySensitive(const Segments *segments) {
     return kSensitive;
   }
 
-  // If the key contains any alphabetical character, treat it as privacy
-  // sensitive. But for common English words, this rule is too strict and
-  // should be relaxed. See b/5995529.
-  // TODO(team): Relax this rule.
-  // There also remains some cases to be considered. Compare following two
-  // cases.
+  // If the key contains any alphabetical character but it is in our dictionary,
+  // it can be treated as privacy nonsensitive word; cf. b/5995529. Besides,
+  // short words would be considered as privacy nonsensitive word as well.
+  if (segment_key.size() <= 3) {
+    return kNonSensitive;
+  }
+  // TODO(noriyukit): The following code performs case-sensitive match. We may
+  // relax the match to case-insensitive one.
+  // TODO(noriyukit): It'd be better if DictionaryInterface has LookupExact()
+  // method.
+  NodeAllocator allocator;
+  Node *node = dictionary_->LookupPredictive(segment_key.c_str(),
+                                             segment_key.size(),
+                                             &allocator);
+  for (; node != NULL; node = node->bnext) {
+    if (node->key == segment_key) {
+      return kNonSensitive;
+    }
+  }
+
+  // If the key contains any alphabetical character and is not in our
+  // dictionary, treat it as privacy sensitive. There also remains some cases to
+  // be considered. Compare following two cases.
   //   Case A:
   //     1. Type "ywwz1sxm" in Roman-input style then get "yっwz1sxm".
   //     2. Hit F10 key to convert it to "ywwz1sxm" by
@@ -206,8 +228,6 @@ bool IsPrivacySensitive(const Segments *segments) {
   return kNonSensitive;
 }
 
-}  // namespace
-
 UserHistoryStorage::UserHistoryStorage(const string &filename)
     : storage_(new storage::EncryptedStringStorage(filename)) {
 }
@@ -322,7 +342,9 @@ class UserHistoryPredictorSyncer : public Thread {
 };
 
 UserHistoryPredictor::UserHistoryPredictor()
-    : updated_(false), dic_(new DicCache(UserHistoryPredictor::cache_size())) {
+    : updated_(false),
+      dic_(new DicCache(UserHistoryPredictor::cache_size())),
+      dictionary_(DictionaryFactory::GetDictionary()) {
   AsyncLoad();  // non-blocking
   // Load()  blocking version can be used if any
 }
@@ -555,23 +577,21 @@ string UserHistoryPredictor::GetRomanMisspelledKey(
 
 // static
 bool UserHistoryPredictor::MaybeRomanMisspelledKey(const string &key) {
-  const char *begin = key.data();
-  const char *end = key.data() + key.size();
   int num_alpha = 0;
   int num_hiragana = 0;
   int num_unknown = 0;
-  while (begin < end) {
-    size_t mblen = 0;
-    const char32 w = Util::UTF8ToUCS4(begin, end, &mblen);
-    begin += mblen;
+  for (ConstChar32Iterator iter(key); !iter.Done(); iter.Next()) {
+    const char32 w = iter.Get();
     const Util::ScriptType type = Util::GetScriptType(w);
     if (type == Util::HIRAGANA || w == 0x30FC) {  // "ー".
       ++num_hiragana;
       continue;
-    } else if (type == Util::UNKNOWN_SCRIPT && num_unknown <= 0) {
+    }
+    if (type == Util::UNKNOWN_SCRIPT && num_unknown <= 0) {
       ++num_unknown;
       continue;
-    } else if (type == Util::ALPHABET && num_alpha <= 0) {
+    }
+    if (type == Util::ALPHABET && num_alpha <= 0) {
       ++num_alpha;
       continue;
     }
@@ -889,6 +909,12 @@ bool UserHistoryPredictor::LookupEntry(
 }
 
 bool UserHistoryPredictor::Predict(Segments *segments) const {
+  ConversionRequest default_request;
+  return PredictForRequest(default_request, segments);
+}
+
+bool UserHistoryPredictor::PredictForRequest(const ConversionRequest &request,
+                                             Segments *segments) const {
   if (!CheckSyncerAndDelete()) {
     LOG(WARNING) << "Syncer is running";
     return false;
@@ -942,7 +968,7 @@ bool UserHistoryPredictor::Predict(Segments *segments) const {
   }
 
   EntryPriorityQueue results;
-  GetResultsFromHistoryDictionary(*segments, prev_entry, &results);
+  GetResultsFromHistoryDictionary(request, *segments, prev_entry, &results);
   if (results.size() == 0) {
     VLOG(2) << "no prefix match candiate is found.";
     return false;
@@ -997,6 +1023,7 @@ const UserHistoryPredictor::Entry *UserHistoryPredictor::LookupPrevEntry(
 }
 
 void UserHistoryPredictor::GetResultsFromHistoryDictionary(
+    const ConversionRequest &request,
     const Segments &segments, const Entry *prev_entry,
     EntryPriorityQueue *results) const {
   DCHECK(results);
@@ -1028,7 +1055,7 @@ void UserHistoryPredictor::GetResultsFromHistoryDictionary(
   string input_key;
   string base_key;
   scoped_ptr<Trie<string> > expanded(NULL);
-  GetInputKeyFromSegments(segments, &input_key, &base_key, &expanded);
+  GetInputKeyFromSegments(request, segments, &input_key, &base_key, &expanded);
 
   int trial = 0;
   for (const DicElement *elm = dic_->Head(); elm != NULL; elm = elm->next) {
@@ -1060,22 +1087,23 @@ void UserHistoryPredictor::GetResultsFromHistoryDictionary(
 
 // static
 void UserHistoryPredictor::GetInputKeyFromSegments(
-    const Segments &segments, string *input_key, string *base,
+    const ConversionRequest &request, const Segments &segments,
+    string *input_key, string *base,
     scoped_ptr<Trie<string> > *expanded) {
   DCHECK(input_key);
   DCHECK(base);
   DCHECK_GE(segments.conversion_segments_size(), 0);
 
-  if (segments.composer() == NULL ||
+  if (!request.has_composer() ||
       !FLAGS_enable_expansion_for_user_history_predictor) {
     *input_key = segments.conversion_segment(0).key();
     *base = segments.conversion_segment(0).key();
     return;
   }
 
-  segments.composer()->GetStringForPreedit(input_key);
+  request.composer().GetStringForPreedit(input_key);
   set<string> expanded_set;
-  segments.composer()->GetQueriesForPrediction(base, &expanded_set);
+  request.composer().GetQueriesForPrediction(base, &expanded_set);
   if (expanded_set.size() > 0) {
     expanded->reset(new Trie<string>);
     for (set<string>::const_iterator itr = expanded_set.begin();
@@ -1662,4 +1690,5 @@ uint32 UserHistoryPredictor::cache_size() {
 uint32 UserHistoryPredictor::max_next_entries_size() {
   return kMaxNextEntriesSize;
 }
+
 }  // namespace mozc
