@@ -237,80 +237,4 @@ TEST_F(CommandRewriterTest, ValueCheck) {
     seg->clear_candidates();
   }
 }
-
-TEST_F(CommandRewriterTest, Finish) {
-  CommandRewriter rewriter;
-  Segments segments;
-  config::Config config;
-
-  Segment *seg = segments.push_back_segment();
-
-  {
-    Segment::Candidate *candidate = seg->add_candidate();
-    candidate->attributes |= Segment::Candidate::COMMAND_CANDIDATE;
-    // candidate->value = "シークレットモードをオン";
-    candidate->value = "\xE3\x82\xB7\xE3\x83\xBC\xE3\x82\xAF"
-        "\xE3\x83\xAC\xE3\x83\x83\xE3\x83\x88"
-        "\xE3\x83\xA2\xE3\x83\xBC\xE3\x83\x89"
-        "\xE3\x82\x92\xE3\x82\xAA\xE3\x83\xB3";
-    config::ConfigHandler::GetConfig(&config);
-    config.set_incognito_mode(false);
-    config::ConfigHandler::SetConfig(config);
-    rewriter.Finish(&segments);
-    config::ConfigHandler::GetConfig(&config);
-    EXPECT_TRUE(config.incognito_mode());
-    seg->clear_candidates();
-  }
-
-  {
-    Segment::Candidate *candidate = seg->add_candidate();
-    candidate->attributes |= Segment::Candidate::COMMAND_CANDIDATE;
-    //    candidate->value = "シークレットモードをオフ";
-    candidate->value = "\xE3\x82\xB7\xE3\x83\xBC\xE3\x82\xAF"
-        "\xE3\x83\xAC\xE3\x83\x83\xE3\x83\x88"
-        "\xE3\x83\xA2\xE3\x83\xBC\xE3\x83\x89"
-        "\xE3\x82\x92\xE3\x82\xAA\xE3\x83\x95";
-    config::ConfigHandler::GetConfig(&config);
-    config.set_incognito_mode(true);
-    config::ConfigHandler::SetConfig(config);
-    rewriter.Finish(&segments);
-    config::ConfigHandler::GetConfig(&config);
-    EXPECT_FALSE(config.incognito_mode());
-    seg->clear_candidates();
-  }
-
-  {
-    Segment::Candidate *candidate = seg->add_candidate();
-    candidate->attributes |= Segment::Candidate::COMMAND_CANDIDATE;
-    //    candidate->value = "サジェスト機能の一時停止";
-    candidate->value = "\xE3\x82\xB5\xE3\x82\xB8\xE3\x82\xA7"
-        "\xE3\x82\xB9\xE3\x83\x88\xE6\xA9\x9F"
-        "\xE8\x83\xBD\xE3\x81\xAE\xE4\xB8\x80"
-        "\xE6\x99\x82\xE5\x81\x9C\xE6\xAD\xA2";
-    config::ConfigHandler::GetConfig(&config);
-    config.set_presentation_mode(false);
-    config::ConfigHandler::SetConfig(config);
-    rewriter.Finish(&segments);
-    config::ConfigHandler::GetConfig(&config);
-    EXPECT_TRUE(config.presentation_mode());
-    seg->clear_candidates();
-  }
-
-  {
-    Segment::Candidate *candidate = seg->add_candidate();
-    candidate->attributes |= Segment::Candidate::COMMAND_CANDIDATE;
-    // candidate->value = "サジェスト機能を元に戻す";
-    candidate->value = "\xE3\x82\xB5\xE3\x82\xB8\xE3\x82\xA7"
-        "\xE3\x82\xB9\xE3\x83\x88\xE6\xA9\x9F"
-        "\xE8\x83\xBD\xE3\x82\x92\xE5\x85\x83"
-        "\xE3\x81\xAB\xE6\x88\xBB\xE3\x81\x99";
-    config::ConfigHandler::GetConfig(&config);
-    config.set_presentation_mode(true);
-    config::ConfigHandler::SetConfig(config);
-    rewriter.Finish(&segments);
-    config::ConfigHandler::GetConfig(&config);
-    EXPECT_FALSE(config.presentation_mode());
-    seg->clear_candidates();
-  }
-}
 }  // namespace mozc
