@@ -40,6 +40,7 @@
 namespace mozc {
 
 template <class T> class ObjectPool;
+class UserPOSInterface;
 
 namespace rewriter {
 
@@ -108,6 +109,7 @@ class DictionaryGenerator {
  private:
   scoped_ptr<ObjectPool<Token> > token_pool_;
   scoped_ptr<map<uint64, Token *> > token_map_;
+  const UserPOSInterface *user_pos_;
 
   DISALLOW_COPY_AND_ASSIGN(DictionaryGenerator);
 };
