@@ -34,6 +34,7 @@
 
 namespace mozc {
 
+class ConversionRequest;
 class Segments;
 
 class RewriterInterface {
@@ -55,9 +56,16 @@ class RewriterInterface {
     return CONVERSION;
   }
 
+  // TODO(noriyukit): Deprecates this method and migrate to RewriteForRequest.
   // Rewrite request and/or result.
   virtual bool Rewrite(Segments *segments) const = 0;
 
+  virtual bool RewriteForRequest(const ConversionRequest &request,
+                                 Segments *segments) const {
+    // Ignore the request by default.
+    return Rewrite(segments);
+  }
+
   // This method is mainly called when user puts SPACE key
   // and changes the focused candidate.
   // In this method, Converter will find bracketing matching.
