@@ -94,7 +94,7 @@ class SessionRegressionTest : public testing::Test {
     config.set_use_realtime_conversion(false);
     config::ConfigHandler::SetConfig(config);
     handler_.reset(new SessionHandler());
-    session_.reset(dynamic_cast<session::Session *>(handler_->NewSession()));
+    ResetSession();
     CHECK(session_.get());
   }
 
@@ -119,7 +119,7 @@ class SessionRegressionTest : public testing::Test {
   void InsertCharacterChars(const string &chars,
                             commands::Command *command) {
     const uint32 kNoModifiers = 0;
-    for (int i = 0; i < chars.size(); ++i) {
+    for (size_t i = 0; i < chars.size(); ++i) {
       command->clear_input();
       command->clear_output();
       commands::KeyEvent *key_event = command->mutable_input()->mutable_key();
@@ -129,6 +129,10 @@ class SessionRegressionTest : public testing::Test {
     }
   }
 
+  void ResetSession() {
+    session_.reset(dynamic_cast<session::Session *>(handler_->NewSession()));
+  }
+
   bool orig_use_history_rewriter_;
   scoped_ptr<SessionHandler> handler_;
   scoped_ptr<session::Session> session_;
@@ -441,4 +445,39 @@ TEST_F(SessionRegressionTest, ConsistencyBetweenPredictionAndSuggesion) {
   EXPECT_EQ(suggestion_first_candidate, prediction_commit_result);
 }
 
+TEST_F(SessionRegressionTest, Transliteration_Issue6209563) {
+  {  // Romaji mode
+    ResetSession();
+    commands::Command command;
+
+    InsertCharacterChars("tt", &command);
+    command.Clear();
+    SendKey("F10", &command);
+    EXPECT_EQ("tt", command.output().preedit().segment(0).value());
+  }
+
+  {  // Kana mode
+    ResetSession();
+    commands::Command command;
+
+    InitSessionToPrecomposition(session_.get());
+    config::Config config;
+    config::ConfigHandler::GetConfig(&config);
+    config.set_preedit_method(config::Config::KANA);
+
+    // Inserts "ち" 5 times
+    for (int i = 0; i < 5; ++i) {
+      command.Clear();
+      commands::KeyEvent *key_event = command.mutable_input()->mutable_key();
+      key_event->set_key_code('a');
+      key_event->set_key_string("\xE3\x81\xA1");  // "ち"
+      session_->InsertCharacter(&command);
+    }
+
+    command.Clear();
+    SendKey("F10", &command);
+    EXPECT_EQ("aaaaa", command.output().preedit().segment(0).value());
+  }
+}
+
 }  // namespace mozc
