@@ -44,8 +44,6 @@ class LRUStorage;
 
 namespace sync {
 
-class ClockTimerInterface;
-
 class LearningPreferenceAdapter : public AdapterInterface {
  public:
   LearningPreferenceAdapter();
@@ -99,11 +97,6 @@ class LearningPreferenceAdapter : public AdapterInterface {
   uint64 GetLastDownloadTimestamp() const;
   bool SetLastDownloadTimestamp(uint64 last_download_time);
 
-  // Inject ClockTimerInterface for unittesting
-  void SetClockTimerInterface(ClockTimerInterface *clock_timer);
-
-  ClockTimerInterface *clock_timer_;
-
   vector<Storage> storages_;
   LearningPreference local_update_;
   uint64 local_update_time_;
