@@ -45,6 +45,10 @@
 #include "win32/base/imm_util.h"  // IsCuasEnabled
 #endif
 
+#ifdef OS_MACOSX
+#include "base/mac_util.h"
+#endif
+
 namespace mozc {
 namespace usage_stats {
 
@@ -289,6 +293,11 @@ bool UsageStats::Send(void *data) {
   UsageStats::SetBoolean("CuasEnabled", win32::ImeUtil::IsCuasEnabled());
 #endif
 
+#ifdef OS_MACOSX
+  UsageStats::SetBoolean("PrelauncherEnabled",
+                         MacUtil::CheckPrelauncherLoginItemStatus());
+#endif
+
   LoadStats(&uploader);
 
   // Just check for confirming that we can insert the value to upload_key.
